@@ -67,6 +67,12 @@ the following install code in your SConstruct::
     from pyscons import PYTOOL
     env = Environment(tools = ['default', PYTOOL(recursive = False, filter_path = lambda p: True)])
 
+Known Issues
+------------
+
+Relative imports do not work. This seems to be a bug in the modulefinder package that I do not 
+know how to fix.
+
 Author
 ------
 
@@ -90,19 +96,18 @@ class PyScanner(MF):
         self.path_filter = path_filter
         MF.__init__(self, *args, **kwargs)
 
-    def scan(self, name, *arg, **karg):
-        self.name = name
-        return MF.run_script(self, name, *arg, **karg) 
-
     def import_hook(self, name, caller, *arg, **karg):
-        if caller.__file__ == self.name:# and self.path_filter(caller.__file__): 
+        if caller.__file__ == self.name: 
             return MF.import_hook(self, name, caller, *arg, **karg) 
 
     def __call__(self, node, env, path):
-        if str(node).split('.')[-1] not in ['py', 'pyc', 'pyo']: 
-            return []
-        self.scan(str(node))
-        return list(m.__file__ for m in self.modules.values() if self.path_filter(m.__file__))
+        if str(node).split('.')[-1] not in ['py', 'pyc', 'pyo']: return []
+        self.modules = {}; self.name = str(node)
+        try: self.run_script(self.name)
+        except: pass
+        imports = list(os.path.abspath(m.__file__) for m in self.modules.values() 
+            if self.path_filter(m.__file__))
+        return imports
 
 def ToList(input):
     if input is None: input = [] 
@@ -149,6 +154,6 @@ class PYTOOL:
 
     def __call__(self, env):
         env.Append(SCANNERS = Scanner(function = PyScanner(self.path_filter), 
-                    name = "PyScanner", skeys = ['.py'], recursive=self.recursive))
+                    name = "PyScanner", skeys = ['.py', '.pyo', '.pyc'], recursive=self.recursive))
         env.AddMethod(_PyScript, "PyScript")
         return env
